quantile-estimator
==========================

Python Implementation of Graham Cormode and S. Muthukrishnan's Effective Computation of Biased Quantiles over Data Streams in ICDE’05

## Installation
```
pip install quantile-estimator==0.1.1
```
